# py-3rdparty-mediawiki
[![Join the discussion](https://img.shields.io/badge/Discussion-github-brightgreen)](https://github.com/WolfgangFahl/py-3rdparty-mediawiki/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/py-3rdparty-mediawiki)](https://pypi.org/project/py-3rdparty-mediawiki/)
[![Github Actions Build](https://github.com/WolfgangFahl/py-3rdparty-mediawiki/workflows/Build/badge.svg?branch=master)](https://github.com/WolfgangFahl/py-3rdparty-mediawiki/actions?query=workflow%3ABuild+branch%3Amaster)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/py-3rdparty-mediawiki.svg)](https://github.com/WolfgangFahl/py-3rdparty-mediawiki/issues)
[![GitHub issues](https://img.shields.io/github/issues-closed/WolfgangFahl/py-3rdparty-mediawiki.svg)](https://github.com/WolfgangFahl/py-3rdparty-mediawiki/issues/?q=is%3Aissue+is%3Aclosed)
[![Docs](https://img.shields.io/readthedocs/py-3rdparty-mediawiki/latest.svg)](https://py-3rdparty-mediawiki.readthedocs.io/en/latest/)
[![GitHub](https://img.shields.io/github/license/WolfgangFahl/py-3rdparty-mediawiki.svg)](https://www.apache.org/licenses/LICENSE-2.0)
[![PyPI Status](https://img.shields.io/pypi/v/py-3rdparty-mediawiki.svg)](https://pypi.python.org/pypi/py-3rdparty-mediawiki/)
[![BITPlan](http://wiki.bitplan.com/images/wiki/thumb/3/38/BITPlanLogoFontLessTransparent.png/198px-BITPlanLogoFontLessTransparent.png)](http://www.bitplan.com)

## Links
* [Python](https://www.python.org/)
* [pywikibot](https://pypi.org/project/pywikibot/)
* [pyLoDStorage](https://github.com/WolfgangFahl/pyLoDStorage)
* [py-3rdparty-mediawiki on pypi](https://pypi.org/project/py-3rdparty-mediawiki)

## Documentation
[Wiki](http://mediawiki-japi.bitplan.com/index.php/py-3rdparty-mediawiki)
